import openai

def OwlSense():
    print("Owl")
    
def ottaha():
    camel_ascii = r"""
     ___.-''''-.
    /___  @    |
    ',,,,.     |         _.'''''''._
         '     |        /           \
         |     \    _.-'             \
         |      '.-'                  '-.
         |                               ',
         |                                '',
          ',,-,                           ':;
               ',,| ;,,                 ,' ;;
                  ! ; !'',,,',',,,,'!  ;   ;:
                 : ;  ! !       ! ! ;  ;   :;
                 ; ;   ! !      ! !  ; ;   ;,
                ; ;    ! !     ! !   ; ;     
                ; ;    ! !    ! !     ; ;
               ;,,      !,!   !,!     ;,;
               /_I      L_I   L_I     /_I
"""
    print(camel_ascii)
    print("Ottaha")

    
    
    
    
# def gpt(OPENAI_API_KEY , models , promopt):

#     openai.api_key = OPENAI_API_KEY
#     response = openai.ChatCompletion.create(
#         model=models,
#         messages=[{"role": "user", "content": f"{promopt}"}]
#     )
#     return(response.choices[0].message.content)
    